@@ -4,7 +4,7 @@ from abc import ABC, abstractmethod
 from collections import defaultdict
 from functools import wraps
 from pathlib import Path
-from typing import Any, Callable, DefaultDict, Dict, List, Optional, Set
+from typing import Any, Callable, DefaultDict, Dict, List, Optional, Set, Union
 
 from jinja2 import Environment, FileSystemLoader, Template
 from pydantic import BaseModel, root_validator
@@ -53,7 +53,11 @@ class DataModelFieldBase(BaseModel):
     imports: List[Import] = []
     type_hint: Optional[str] = None
     unresolved_types: List[str] = []
-    field: Optional[str]
+
+    @property
+    def field(self) -> Optional[str]:
+        """for backwards compatibility"""
+        return None
 
     @optional
     def _get_type_hint(self) -> Optional[str]:
@@ -70,13 +74,15 @@ class DataModelFieldBase(BaseModel):
             return type_hint
         if self.is_list:
             self.imports.append(IMPORT_LIST)
-            if self.is_union:
-                self.imports.append(IMPORT_UNION)
-                return f'{LIST}[{UNION}[{type_hint}]]'
-            return f'{LIST}[{type_hint}]'
+            self.imports.append(IMPORT_UNION)
+            return f'{LIST}[{UNION}[{type_hint}]]'
         self.imports.append(IMPORT_UNION)
         return f'{UNION}[{type_hint}]'
 
+    @property
+    def method(self) -> Optional[str]:
+        return None
+
     @root_validator
     def validate_root(cls, values: Any) -> Dict[str, Any]:
         name = values.get('name')
@@ -102,6 +108,10 @@ class DataModelFieldBase(BaseModel):
                 self.imports.extend(data_type.imports_)
         self.type_hint = self._get_type_hint()
 
+    @property
+    def represented_default(self) -> str:
+        return repr(self.default)
+
 
 class TemplateBase(ABC):
     def __init__(self, template_file_path: Path) -> None:
@@ -147,6 +157,7 @@ class DataModel(TemplateBase, ABC):
         imports: Optional[List[Import]] = None,
         auto_import: bool = True,
         reference_classes: Optional[List[str]] = None,
+        methods: Optional[List[str]] = None,
     ) -> None:
         if not self.TEMPLATE_FILE_PATH:
             raise Exception('TEMPLATE_FILE_PATH is undefined')
@@ -206,6 +217,8 @@ class DataModel(TemplateBase, ABC):
             for field in self.fields:
                 self.imports.extend(field.imports)
 
+        self.methods: List[str] = methods or []
+
         super().__init__(template_file_path=template_file_path)
 
     def render(self) -> str:
@@ -214,6 +227,7 @@ class DataModel(TemplateBase, ABC):
             fields=self.fields,
             decorators=self.decorators,
             base_class=self.base_class,
+            methods=self.methods,
             **self.extra_template_data,
         )
         return response
