@@ -120,29 +120,6 @@ class JsonSchemaObject(BaseModel):
             return None
         return values
 
-    @property
-    def typed_default(self) -> Union[str, bool, Dict[Any, Any], None]:
-        if self.default and self.type:
-            type_ = self.type[0] if isinstance(self.type, list) else self.type
-            return self._get_typed_default(type_, self.default)
-        return None
-
-    @classmethod
-    def _get_typed_default(
-        cls, type_: str, default_value: Any
-    ) -> Union[str, bool, Dict[Any, Any], None]:
-        if type_ == 'integer' or type_ == 'number':
-            return default_value
-        elif type_ == 'boolean':
-            if default_value == 'true':
-                return True
-            return False
-        elif type_ == 'object' and isinstance(default_value, dict):
-            return default_value
-        elif type_ == 'null':
-            return None
-        return f"'{default_value}'"
-
 
 JsonSchemaObject.update_forward_refs()
 
@@ -195,9 +172,9 @@ class JsonSchemaParser(Parser):
         ]
 
     def get_class_name(self, field_name: str, unique: bool = True) -> str:
-        field_name = get_valid_name(field_name)
         if '.' in field_name:
-            prefix, field_name = field_name.rsplit('.', 1)
+            split_name = [get_valid_name(n, set()) for n in field_name.split('.')]
+            prefix, field_name = '.'.join(split_name[:-1]), split_name[-1]
             prefix += '.'
         else:
             prefix = ''
@@ -315,7 +292,7 @@ class JsonSchemaParser(Parser):
             is_list: bool = False
             is_union: bool = False
             field_types: List[DataType]
-            field_name, alias = get_valid_field_name_and_alias(field_name)
+            field_name, alias = get_valid_field_name_and_alias(field_name, set())
             if field.ref:
                 field_types = [
                     self.data_type(
@@ -326,10 +303,10 @@ class JsonSchemaParser(Parser):
                 ]
             elif field.is_array:
                 class_name = self.get_class_name(field_name)
-                array_fields, array_field_classes = self.parse_array_fields(
+                array_field, array_field_classes = self.parse_array_fields(
                     class_name, field
                 )
-                field_types = array_fields[0].data_types
+                field_types = array_field.data_types
                 is_list = True
                 is_union = True
             elif field.anyOf:
@@ -371,7 +348,7 @@ class JsonSchemaParser(Parser):
                     name=field_name,
                     example=field.examples,
                     description=field.description,
-                    default=field.typed_default,
+                    default=field.default,
                     title=field.title,
                     data_types=field_types,
                     required=required,
@@ -398,7 +375,7 @@ class JsonSchemaParser(Parser):
 
     def parse_array_fields(
         self, name: str, obj: JsonSchemaObject
-    ) -> Tuple[List[DataModelFieldBase], List[DataType]]:
+    ) -> Tuple[DataModelFieldBase, List[DataType]]:
         if isinstance(obj.items, JsonSchemaObject):
             items = [obj.items]
         else:
@@ -434,27 +411,32 @@ class JsonSchemaParser(Parser):
                 item_obj_data_types.append(
                     self.data_type(type=enum.name, ref=True, version_compatible=True)
                 )
-
+            elif item.is_array:
+                class_name = self.get_class_name(name)
+                array_field, array_field_classes = self.parse_array_fields(
+                    class_name, item
+                )
+                item_obj_data_types.extend(array_field.data_types)
             else:
                 item_obj_data_types.extend(self.get_data_type(item))
 
         field = self.data_model_field_type(
             data_types=item_obj_data_types,
             example=obj.examples,
-            default=obj.typed_default,
+            default=obj.default,
             description=obj.description,
             title=obj.title,
             required=True,
             is_list=True,
             is_union=is_union,
         )
-        return [field], item_obj_data_types
+        return field, item_obj_data_types
 
     def parse_array(self, name: str, obj: JsonSchemaObject) -> None:
-        fields, item_obj_names = self.parse_array_fields(name, obj)
+        field, item_obj_names = self.parse_array_fields(name, obj)
         data_model_root = self.data_model_root_type(
             name,
-            fields,
+            [field],
             custom_base_class=self.base_class,
             custom_template_dir=self.custom_template_dir,
             extra_template_data=self.extra_template_data,
@@ -486,7 +468,7 @@ class JsonSchemaParser(Parser):
                     data_types=types,
                     description=obj.description,
                     example=obj.examples,
-                    default=obj.typed_default,
+                    default=obj.default,
                     required=not obj.nullable,
                 )
             ],
